@@ -24,7 +24,6 @@ class SnovioAPI:
         'domain-emails-with-info',
         'prospect-finished', 'get-emails-replies', 'get-emails-clicked',
         'get-user-campaigns', 'emails-sent',
-        'get-prospect-by-id', 'get_prospects_by_email',
         'prospect-custom-fields', 'get-user-lists',
         'get-balance'
     ]
@@ -79,7 +78,6 @@ class SnovioAPI:
             return response
 
         elif response.status_code == 401:
-            print('Refreshing token')
             if self.is_parameter_in_uri(endpoint):
                 endpoint = self.update_endpoint_with_query_params(endpoint, data)
                 data = {}
@@ -99,6 +97,9 @@ class SnovioAPI:
                 )
             return response.json()
 
+        elif response.status_code == 403:
+            raise SnovioError('Unauthorised')
+
     def __getattr__(self, name):
         def wrapper(data={}):
             response = self._request(name.replace('_', '-'), data)
